@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -111,53 +111,42 @@ class AlertComponent extends React.Component {
     };
 
     this.handleCreateCredential = this.handleCreateCredential.bind(this);
-    this.handleEmailCredentialChange = this.handleEmailCredentialChange.bind(
-      this,
-    );
+    this.handleEmailCredentialChange =
+      this.handleEmailCredentialChange.bind(this);
     this.handleFilterIdChange = this.handleFilterIdChange.bind(this);
     this.handleTestAlert = this.handleTestAlert.bind(this);
-    this.handlePasswordOnlyCredentialChange = this.handlePasswordOnlyCredentialChange.bind(
-      this,
-    );
+    this.handlePasswordOnlyCredentialChange =
+      this.handlePasswordOnlyCredentialChange.bind(this);
     this.handleScpCredentialChange = this.handleScpCredentialChange.bind(this);
     this.handleSaveComposerContent = this.handleSaveComposerContent.bind(this);
     this.handleSmbCredentialChange = this.handleSmbCredentialChange.bind(this);
     this.handleValueChange = this.handleValueChange.bind(this);
-    this.handleVeriniceCredentialChange = this.handleVeriniceCredentialChange.bind(
-      this,
-    );
-    this.handleTippingPointCredentialChange = this.handleTippingPointCredentialChange.bind(
-      this,
-    );
-    this.handleVfireCredentialChange = this.handleVfireCredentialChange.bind(
-      this,
-    );
+    this.handleVeriniceCredentialChange =
+      this.handleVeriniceCredentialChange.bind(this);
+    this.handleTippingPointCredentialChange =
+      this.handleTippingPointCredentialChange.bind(this);
+    this.handleVfireCredentialChange =
+      this.handleVfireCredentialChange.bind(this);
     this.handleReportFormatsChange = this.handleReportFormatsChange.bind(this);
 
     this.openAlertDialog = this.openAlertDialog.bind(this);
     this.handleCloseAlertDialog = this.handleCloseAlertDialog.bind(this);
-    this.handleOpenContentComposerDialog = this.handleOpenContentComposerDialog.bind(
-      this,
-    );
-    this.closeContentComposerDialog = this.closeContentComposerDialog.bind(
-      this,
-    );
-    this.openPasswordOnlyCredentialDialog = this.openPasswordOnlyCredentialDialog.bind(
-      this,
-    );
+    this.handleOpenContentComposerDialog =
+      this.handleOpenContentComposerDialog.bind(this);
+    this.closeContentComposerDialog =
+      this.closeContentComposerDialog.bind(this);
+    this.openPasswordOnlyCredentialDialog =
+      this.openPasswordOnlyCredentialDialog.bind(this);
     this.openScpCredentialDialog = this.openScpCredentialDialog.bind(this);
     this.openSmbCredentialDialog = this.openSmbCredentialDialog.bind(this);
-    this.openVeriniceCredentialDialog = this.openVeriniceCredentialDialog.bind(
-      this,
-    );
+    this.openVeriniceCredentialDialog =
+      this.openVeriniceCredentialDialog.bind(this);
     this.openVfireCredentialDialog = this.openVfireCredentialDialog.bind(this);
-    this.openTippingPointCredentialDialog = this.openTippingPointCredentialDialog.bind(
-      this,
-    );
+    this.openTippingPointCredentialDialog =
+      this.openTippingPointCredentialDialog.bind(this);
     this.openEmailCredentialDialog = this.openEmailCredentialDialog.bind(this);
-    this.handleCloseCredentialDialog = this.handleCloseCredentialDialog.bind(
-      this,
-    );
+    this.handleCloseCredentialDialog =
+      this.handleCloseCredentialDialog.bind(this);
   }
 
   handleCreateCredential(credentialdata) {
@@ -419,7 +408,7 @@ class AlertComponent extends React.Component {
             : undefined;
 
           const tp_sms_credential_id = isDefined(method.data.tp_sms_credential)
-            ? getValue(method.data.tp_sms_credential.credential)
+            ? getValue(method.data.tp_sms_credential)
             : undefined;
 
           const recipient_credential_id = isDefined(
@@ -552,6 +541,7 @@ class AlertComponent extends React.Component {
               DEFAULT_SCP_PATH,
             ),
             method_data_scp_host: getValue(method.data.scp_host, ''),
+            method_data_scp_port: getValue(method.data.scp_port, 22),
             method_data_scp_known_hosts: getValue(
               method.data.scp_known_hosts,
               '',
@@ -573,6 +563,10 @@ class AlertComponent extends React.Component {
               method.data.smb_file_path_type,
               '',
             ),
+            method_data_smb_max_protocol: getValue(
+              method.data.smb_max_protocol,
+              '',
+            ),
             method_data_smb_report_format: getValue(
               method.data.smb_report_format,
               '',
@@ -603,13 +597,14 @@ class AlertComponent extends React.Component {
               '',
             ),
             method_data_tp_sms_tls_workaround: parseYesNo(
-              getValue(method.data.tp_sms_hostname, NO_VALUE),
+              getValue(method.data.tp_sms_tls_workaround, NO_VALUE),
             ),
 
-            method_data_verinice_server_report_format: select_verinice_report_id(
-              report_formats,
-              getValue(method.data.verinice_server_report_format),
-            ),
+            method_data_verinice_server_report_format:
+              select_verinice_report_id(
+                report_formats,
+                getValue(method.data.verinice_server_report_format),
+              ),
             method_data_verinice_server_url: getValue(
               method.data.verinice_server_url,
             ),
@@ -732,6 +727,7 @@ class AlertComponent extends React.Component {
             method_data_scp_path: DEFAULT_SCP_PATH,
             method_data_scp_report_format: report_format_id,
             method_data_scp_host: undefined,
+            method_data_scp_port: 22,
             method_data_scp_known_hosts: undefined,
             method_data_send_port: undefined,
             method_data_send_host: undefined,
@@ -753,9 +749,8 @@ class AlertComponent extends React.Component {
             method_data_smb_share_path: undefined,
             method_data_smb_file_path: undefined,
             method_data_smb_file_path_type: undefined,
-            method_data_verinice_server_report_format: select_verinice_report_id(
-              report_formats,
-            ),
+            method_data_verinice_server_report_format:
+              select_verinice_report_id(report_formats),
             method_data_pkcs12_credential: UNSET_VALUE,
             method_data_vfire_credential: undefined,
             method_data_vfire_base_url: undefined,
@@ -965,6 +960,7 @@ class AlertComponent extends React.Component {
       method_data_scp_report_format,
       method_data_scp_path,
       method_data_scp_host,
+      method_data_scp_port,
       method_data_scp_known_hosts,
       method_data_send_port,
       method_data_send_host,
@@ -972,6 +968,7 @@ class AlertComponent extends React.Component {
       method_data_smb_credential,
       method_data_smb_file_path,
       method_data_smb_file_path_type,
+      method_data_smb_max_protocol,
       method_data_smb_report_format,
       method_data_smb_share_path,
       method_data_snmp_agent,
@@ -1085,6 +1082,7 @@ class AlertComponent extends React.Component {
                 method_data_scp_report_format={method_data_scp_report_format}
                 method_data_scp_path={method_data_scp_path}
                 method_data_scp_host={method_data_scp_host}
+                method_data_scp_port={method_data_scp_port}
                 method_data_scp_known_hosts={method_data_scp_known_hosts}
                 method_data_send_port={method_data_send_port}
                 method_data_send_host={method_data_send_host}
@@ -1092,6 +1090,7 @@ class AlertComponent extends React.Component {
                 method_data_smb_credential={method_data_smb_credential}
                 method_data_smb_file_path={method_data_smb_file_path}
                 method_data_smb_file_path_type={method_data_smb_file_path_type}
+                method_data_smb_max_protocol={method_data_smb_max_protocol}
                 method_data_smb_report_format={method_data_smb_report_format}
                 method_data_smb_share_path={method_data_smb_share_path}
                 method_data_snmp_agent={method_data_snmp_agent}
